clear all;
%required inputs
%geomtry
sample=10;
z_top=(randn(sample,1) * 0.5 ) + 5; %height of the ice bluff
x_edge=14; % width of typical ice wedge
dt=600; % time step , by default it is 10 min
beach_level=0;
%temperature of the wave
T_a=3;

%calibration parameter

alpha=1;
z_p=0;

% physical properties of the system
p_b=1400; % density of ice bluffs. in kg/m3
T_ice=1e4;% tensile strenght of ice
T_b=2e5;% tensile strength of bluff
%wind speed
% U will be a time series

[tq Uq]=f_wind(dt);
%now wind data is gathered- time in tq and values in Uq

tq_timer=numel(tq);% we take number of time the program should run
%for every tq values we need storm surge level

for i=1:1:tq_timer
    n(i)=-1.45*alpha+f_storm(Uq(i));
end



%at this point we have time step values (tq), corresponding wind speed(Uq)
%and storm surge level(n)

% we need to decide whether storm surge level is critical or not
% we only run niche growth model if the water level is positive
% that means n values has to be greater than 0, otherwise niche growth
% model will not triggered

%we need to convert n values to water depth at base h

for i=1:1:tq_timer
    if n(i)<0
        h(i)=0;
    else
        h(i)=n(i);
    end
end
i=1;
x_m(1)=0;

x_critical=critical_niche(x_edge,p_b,T_ice,T_b,z_top);
y(1)=0;

for i=1:1:(tq_timer-1)
   
    x_m(i+1)=f_niche_growth(T_a,h(i),tq(i),tq(i+1));
     x_m(2)=0;
  
  
end
x_m(2)=0;
y=cumsum(x_m);
t_day=tq/3600/24;


figure
ax1=subplot(3,1,1)
plot(t_day,y,'linewidth',2)
grid on;
grid minor;
y_target='niche growth (m)';
% title('niche growth model')
% xlabel('time (day)','FontSize',12,'FontWeight','bold','Color','b')
ylabel(y_target,'FontSize',12,'FontWeight','bold','Color','b')
ylim([0 75])



ax2=subplot(3,1,2)
plot(t_day,Uq,'linewidth',0.5)
grid on;
grid minor;
y_target='wind speed (m/s)';
% title('wind speed (June 2012-June 2013)')
xlabel('time (day)','FontSize',12,'FontWeight','bold','Color','b')
ylabel(y_target,'FontSize',12,'FontWeight','bold','Color','b')


ax3=subplot(3,1,3)
plot(t_day,h,'linewidth',2)
grid on;
grid minor;
y_target='water depth(m)';
% title('wind speed over time')
% xlabel('time (day)','FontSize',12,'FontWeight','bold','Color','b')
ylabel(y_target,'FontSize',12,'FontWeight','bold','Color','b')

