%required inputs
%geomtry
sample=1000;
z_top=(randn(sample,1) * 0.5 ) + 5; %height of the ice bluff
x_edge=(randn(sample,1) * 2 ) + 14; % width of typical ice wedge
dt=600; % time step , by default it is 10 min
beach_level=0;
%temperature of the wave
T_a=(randn(sample,1) * 0.3 ) + 3;

%calibration parameter

alpha=-.28;

z_p=0;

% physical properties of the system
p_b=1400; % density of ice bluffs. in kg/m3
T_ice=1e4;% tensile strenght of ice
T_b=2e5;% tensile strength of bluff
%wind speed
% U will be a time series

[tq Uq]=f_wind(dt);
%now wind data is gathered- time in tq and values in Uq

tq_timer=numel(tq);% we take number of time the program should run
%for every tq values we need storm surge level
n=1:1:tq_timer;%declaring variable
h=n;%initial condition
for i=1:1:tq_timer
    n(i)=alpha+f_storm(Uq(i));
end


%% 

%at this point we have time step values (tq), corresponding wind speed(Uq)
%and storm surge level(n)

% we need to decide whether storm surge level is critical or not
% we only run niche growth model if the water level is positive
% that means n values has to be greater than 0, otherwise niche growth
% model will not triggered

%we need to convert n values to water depth at base h

for i=1:1:tq_timer
    if n(i)<0
        h(i)=0;
    else
        h(i)=n(i);
    end
end
figure

ax1=subplot(3,1,1)
plot(tq/3600/24 ,Uq)
grid on;
grid minor;
xlabel('time (day)','FontSize',12,'FontWeight','bold','Color','b')
ylabel('wind speed (m/s)','FontSize',12,'FontWeight','bold','Color','b')
xlim([0 365])

ax2=subplot(3,1,2)
plot(tq/3600/24 ,n+2)
grid on;
grid minor;
xlabel('time (day)','FontSize',12,'FontWeight','bold','Color','b')
ylabel('surge level(m)','FontSize',12,'FontWeight','bold','Color','b')
xlim([0 365])

ax3=subplot(3,1,3)
plot(tq/3600/24 ,h)
grid on;
grid minor;
xlabel('time (day)','FontSize',12,'FontWeight','bold','Color','b')
ylabel('inundation depth (m)','FontSize',12,'FontWeight','bold','Color','b')
xlim([0 365])

%% 

i=1;
x_m(1)=0;
x_critical=1:1:sample;
for i=1:1:sample
    x_critical(i)=critical_niche(x_edge(i),p_b,T_ice,T_b,z_top(i));
end
x_critical_mean=normfit(x_critical);

%% 
beta=3/(x_critical_mean*x_edge);
x_m(tq_timer,sample)=0.00;
y(sample)=0;
for j=1:1:sample
    y(1,j)=0;

    for i=1:1:(tq_timer-1)
           x_m(i+1,j)=f_niche_growth(T_a(j),h(i),tq(i),tq(i+1));
        x_m(2,j)=0;
    
    end
x_m(2,j)=0;
y=cumsum(x_m);

end
%% 

t_day=tq/3600/24;



%% 

figure
h1=subplot(4,1,4)

for i=1:1:sample
   
   h2a=plot(t_day,y(:,i),'-b', 'LineWidth',1);
   h2a.Color(4)=0.01; 
   hold on,
      end

for i=1:1:52555
    [value sigma]=normfit(y(i,:));
   mean_1(i)=value;
end
plot(t_day,mean_1, '--y','linewidth',1)


grid on;
grid minor;
xlabel('time (day)')
ylabel('erosion (m)')
xlim([0 365])


ax2=subplot(4,1,1)
plot(t_day,Uq,'linewidth',0.5)
grid on;
grid minor;

xlabel('time (day)')
ylabel('wind speed')
xlim([0 365])

ax3=subplot(4,1,3)
plot(t_day,h,'linewidth',1)
grid on;
grid minor;
ylabel('inundation depth')
xlim([0 365])


ax2=subplot(4,1,2)
plot(tq/3600/24 ,n+2)
grid on;
grid minor;
ylabel('surge level(m)')
xlim([0 365])


%% 

figure
ax1=subplot(2,1,1)
result_B=sort(y(52500,:));
histogram(result_B,30,'Normalization','pdf')
hold on,
[mean, std,mean95,std95]=normfit(result_B,0.05);
dim=[0.7,.8,0.2,0.1];
str={strcat('mean=', num2str(mean)),strcat('std=', num2str(std))};
annotation('textbox',dim,'String',str)
f = exp(-(result_B-mean).^2./(2*std^2))./(std*sqrt(2*pi));
plot(result_B,f,'LineWidth',1.5)
xlabel('shore erosion (m)','FontSize',12,'FontWeight','bold','Color','b')
ylabel('pdf','FontSize',12,'FontWeight','bold','Color','b')

ax1=subplot(2,1,2)
normplot(result_B)
xlabel('shore erosion (m)','FontSize',12,'FontWeight','bold','Color','b')
ylabel('probability','FontSize',12,'FontWeight','bold','Color','b')
